runQA: Start LC/MS QA application

View source: R/runQA.R

runQAR Documentation

Start LC/MS QA application

Description

Runs a 'shiny' application to check the quality of LC/MS experiment. The system's default web browser will be launched automatically after the app is started.

Usage

runQA()

Value

This function normally does not return; interrupt R to stop the application (usually by pressing Ctrl + C or ESC)

Examples


## Please check the package vignette for details on how to use the app
if (interactive()) {
  runQA()
}


LCMSQA documentation built on May 29, 2024, 3:09 a.m.