| runQA | R Documentation |
Runs a 'shiny' application to check the quality of LC/MS experiment. The system's default web browser will be launched automatically after the app is started.
runQA()
This function normally does not return; interrupt R to stop the application (usually by pressing Ctrl + C or ESC)
## Please check the package vignette for details on how to use the app
if (interactive()) {
runQA()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.